@@ -5,6 +5,7 @@
 #' @param geom either \code{"ecdf"} or \code{"boxplot"} determines how residuals shall be summarized
 #' @param lossFunction function that calculates the loss for a model based on model residuals. By default it's the root mean square.
 #' @param show_outliers number of largest residuals to be presented (only when geom = boxplot).
+#' @param ptlabel either \code{"name"} or \code{"index"} determines the naming convention of the outliers
 #'
 #' @return An object of the class 'model_performance_explainer'.
 #'
@@ -35,31 +36,38 @@
 #' plot(mp_rf, mp_glm, mp_lm, geom = "boxplot", show_outliers = 1)
 #'  }
 #'
-plot.model_performance_explainer <- function(x, ..., geom = "ecdf", show_outliers = 0, lossFunction = function(x) sqrt(mean(x^2))) {
+plot.model_performance_explainer <- function(x, ..., geom = "ecdf", show_outliers = 0, ptlabel = "name", lossFunction = function(x) sqrt(mean(x^2))) {
+  if (!(ptlabel %in% c("name", "index"))){
+    stop("The plot.model_performance() function requires label to be name or index.")
+  }
   df <- x
   class(df) <- "data.frame"
-
+  df$name <- seq.int(nrow(df))
   dfl <- list(...)
   if (length(dfl) > 0) {
     for (resp in dfl) {
       class(resp) <- "data.frame"
+      resp$name <- seq.int(nrow(resp))
       df <- rbind(df, resp)
     }
   }
   df$label <- reorder(df$label, df$diff, lossFunction)
   label <- name <- NULL
+  if (ptlabel == "name") {
+    df$name <- NULL
+    df$name <- rownames(df)
+  }
   if (geom == "ecdf") {
-     pl <-   ggplot(df, aes(abs(diff), color = label)) +
-       stat_ecdf(geom = "step") +
-       stat_ecdf(geom = "point") +
-       theme_mi2() +
-       scale_color_brewer(name = "Model", type = "qual", palette = "Dark2") +
-       xlab("| residuals |") +
-       scale_y_continuous(breaks = seq(0,1,0.1),
-                          labels = paste(seq(100,0,-10),"%"),
-                          trans = "reverse",
-                          name = "") +
-       ggtitle("Distribution of | residuals |")
+    pl <-   ggplot(df, aes(abs(diff), color = label)) +
+      stat_ecdf(geom = "step") +
+      theme_mi2() +
+      scale_color_brewer(name = "Model", type = "qual", palette = "Dark2") +
+      xlab(expression(group("|", residual, "|"))) +
+      scale_y_continuous(breaks = seq(0,1,0.1),
+                         labels = paste(seq(100,0,-10),"%"),
+                         trans = "reverse",
+                         name = "") +
+      ggtitle(expression(paste("Distribution of ", group("|", residual, "|"))))
   } else {
     pl <- ggplot(df, aes(x=label, y=abs(diff), fill = label)) +
       stat_boxplot(alpha=0.4, coef = 1000) +
@@ -67,11 +75,13 @@ plot.model_performance_explainer <- function(x, ..., geom = "ecdf", show_outlier
       theme_mi2() +
       scale_fill_brewer(name = "Model", type = "qual", palette = "Dark2") +
       ylab("") + xlab("") +
-      ggtitle("Boxplots of | residuals |", "Red dot stands for root mean square of residuals") +
+      ggtitle(
+        expression(paste("Boxplots of ", group("|", residual, "|"))),
+        "Red dot stands for root mean square of residuals"
+      ) +
       coord_flip()
     if (show_outliers > 0) {
       df$rank <- unlist(tapply(-abs(df$diff), df$label, rank, ties.method = "min"))
-      df$name <- rownames(df)
       df_small <- df[df$rank <= show_outliers,]
       pl <- pl +
         geom_point(data = df_small) +
